soam.reporting package
======================

Submodules
----------

soam.reporting.gsheets\_report module
-------------------------------------

.. automodule:: soam.reporting.gsheets_report
   :members:
   :undoc-members:
   :show-inheritance:

soam.reporting.mail\_report module
----------------------------------

.. automodule:: soam.reporting.mail_report
   :members:
   :undoc-members:
   :show-inheritance:

soam.reporting.pdf\_report module
---------------------------------

.. automodule:: soam.reporting.pdf_report
   :members:
   :undoc-members:
   :show-inheritance:

soam.reporting.slack\_report module
-----------------------------------

.. automodule:: soam.reporting.slack_report
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: soam.reporting
   :members:
   :undoc-members:
   :show-inheritance:
